#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const fs_1 = __importDefault(require("fs"));
const merge_1 = require("./merge");
const options = new commander_1.Command()
    .requiredOption('-i, --input-file <inputFiles...>', 'input file(s)/merge origin(s)')
    .requiredOption('-d, --destination-file <destinationFile>', 'merge destination')
    .option('-o, --output-file <outputFile>', 'output file, if not provided "merge destination" is overwritten')
    .option('-e, --exclude-file <excludeFiles...>', 'exclude all unit ids of the provided file(s)')
    .option('--no-match-fuzzy', 'prevent fuzzy matching of similar units with changed id')
    .option('--no-collapse-whitespace', 'prevent collapsing of multiple whitespaces and trimming when comparing translations sources')
    .option('--no-reset-translation-state', 'prevent (re-)setting the translation state to new/initial for new/changed units')
    .option('--no-replace-apostrophe', 'prevent replacing of apostrophes (\') with "&apos;"')
    .option('-w, --overwrite-with-translated', 'overwrite target of destination with target of source, if it\'s translated and destination target not')
    .option('--debug', 'enable debug output')
    .parse()
    .opts();
if (!options.debug) {
    console.debug = () => null;
}
const inFilesContent = options.inputFile.map(inputFile => fs_1.default.readFileSync(inputFile, { encoding: 'utf8' }));
const destFileContent = fs_1.default.existsSync(options.destinationFile) ? fs_1.default.readFileSync(options.destinationFile, { encoding: 'utf8' }) : '';
const outString = (0, merge_1.merge)(inFilesContent, destFileContent, {
    excludeFiles: options.excludeFile,
    fuzzyMatch: options.matchFuzzy,
    collapseWhitespace: options.collapseWhitespace,
    resetTranslationState: options.resetTranslationState,
    replaceApostrophe: options.replaceApostrophe,
    overwriteTargetWithTranslated: options.overwriteWithTranslated,
}, options.destinationFile);
fs_1.default.writeFileSync((_a = options.outputFile) !== null && _a !== void 0 ? _a : options.destinationFile, outString, { encoding: 'utf8' });
